@@ -17,7 +17,7 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.4';
+our $VERSION = 'v0.2.5';
 
 
 has resolver => (
@@ -98,6 +98,12 @@ sub _build_robots {
             domain => qr/\.google(?:bot)?\.com$/,
         },
 
+        {
+            name   => 'InfoTiger',
+            agent  => qr/\bInfoTigerBot\b/,
+            domain => qr/\.infotiger\.com$/,
+        },
+
         {
             name   => 'IONOS',
             agent  => qr/\bIonCrawl\b/,
@@ -254,7 +260,7 @@ Robots::Validate - Validate that IP addresses are associated with known robots
 
 =head1 VERSION
 
-version v0.2.4
+version v0.2.5
 
 =head1 SYNOPSIS
 
